<?php
class Pm_Lead_Filter_AdminPage
{
	private $options;
	private $plugin_slug;
	private $plugin_version;

	public function __construct( Pm_Lead_Filter_Options $options, $plugin_slug, $plugin_version ) {
		$this->options = $options;
		$this->shared_options = get_option( '_pm_pluginmill_shared' );
		$this->campaigns = get_option('pm_lead_filter_campaigns');
		$this->plugin_slug = $plugin_slug;
		$this->plugin_version = $plugin_version;
		$this->admin = new Pm_Lead_Filter_Admin( $this->plugin_slug, $this->plugin_version );
	}

	/*
	 * Add admin page to the menu
	 */
	public function addOptionsPage() {
		$settings = add_options_page(
			__(PM_LEAD_FLTR_PLUGIN_NAME.' Settings', 'pm-lead-filter'),
			__(PM_LEAD_FLTR_PLUGIN_NAME, 'pm-lead-filter'),
			'edit_posts',
			'pm_lead_filter',
			array($this, 'render')
		);
		// Load admin scripts when above page is called
  		add_action( 'load-'.$settings, array( $this->admin, 'enqueue_styles' ) );
  		add_action( 'load-'.$settings, array( $this->admin, 'enqueue_scripts' ) );
	}

	/*
	 * Renders admin page container using Settings API
	 */
	public function render(){
		$tab = ( isset( $_GET['tab'] )  ? $_GET['tab'] : 'campaigns' );
		$settings_section = 'pm_lead_filter_'.$tab.'_tab';
		?>
		<div class="wrap">
			<h2><?php _e(PM_LEAD_FLTR_PLUGIN_NAME.' Settings', 'pm-lead-filter'); ?></h2>
			<?php $this->render_page_tabs(); ?>
			<form action="options.php" method="POST">
				<?php
				settings_fields( 'pm_lead_filter_opts' );				
				do_settings_sections( $settings_section );
				if( $tab != 'campaigns' ) {
				submit_button( 'Save Changes', 'primary', 'pm_lead_filter_opts[submit-'.$tab.']', false, array( 'id' => 'submit-'.$tab ) );
				}
				?>
			</form>
		</div>
		<?php
	}

	/*
	 * Define Tabs
	 */
	public function define_page_tabs() {
		$tabs = array(
			'campaigns' => __('Campaigns', 'pm-lead-filter'),
			'display' => __('Display', 'pm-lead-filter'),
			'services' => __('Email Services', 'pm-lead-filter'),
			//'license' => __('License', 'pm-lead-filter'),
			);
		return $tabs;
	}

	/*
	 * Render Tabs
	 */
	public function render_page_tabs( $current = 'campaigns' ) {
		// Determine which tab to display
		if( isset( $_GET['tab'] ) ) :
			$current = $_GET['tab'];
		else:
			$current = 'campaigns';
		endif;

		// Get list of tabs
		$tabs = $this->define_page_tabs();
		$links = array();

		// Create links for each tab
		foreach ($tabs as $tab => $name) :
			if( $tab == $current ) :
				$links[] = '<a class="nav-tab nav-tab-active" href="?page=pm_lead_filter&tab='.$tab.'">'.$name.'</a>';
			else :
				$links[] = '<a class="nav-tab" href="?page=pm_lead_filter&tab='.$tab.'">'.$name.'</a>';
			endif;
		endforeach;

		echo '<h2 class="nav-tab-wrapper">';
		foreach ( $links as $link ) {
			echo $link;
		}
		echo '</h2>';
	}

	/**
	 * Configure the options page using Settings API
	 */
	public function configure() {
		// Register setting
		register_setting( 'pm_lead_filter_opts', 'pm_lead_filter_opts', array($this, 'sanitize') );

		// Add sections
		add_settings_section( 'pm_campaigns_section', __('Create & Edit', 'pm-lead-filter'), array($this, 'renderGeneralSection'), 'pm_lead_filter_campaigns_tab' );
		add_settings_section( 'pm_lead_filter_display', __('Display Options', 'pm-lead-filter'), array($this, 'renderDisplaySection'), 'pm_lead_filter_display_tab' );
		add_settings_section( 'pm_lead_filter_api_keys', __('API Keys', 'pm-lead-filter'), array($this, 'renderApiKeysSection') , 'pm_lead_filter_services_tab' );
		add_settings_section(
			'license_section',
			__('Plugin Mill Support License', 'pm-lead-filter'),
			array($this, 'renderLicenseSection'),
			'pm_lead_filter_license_tab'
			);

		// Fields
		/*
		add_settings_field(
			'pm_lead_filter_show_all',
			__('Show on all pages', 'pm-lead-filter'),
			array($this, 'renderShowAllField'),
			'pm_lead_filter_display_tab',
			'pm_lead_filter_display',
			array()
		);*/
		add_settings_field(
			'pm_lead_filter_homepage',
			__('Enable on Home page', 'pm-lead-filter'),
			array($this, 'renderHomepageField'),
			'pm_lead_filter_display_tab',
			'pm_lead_filter_display',
			array()
		);
		add_settings_field(
			'pm_lead_filter_home_campaign',
			__('Campaign', 'pm-lead-filter'),
			array($this, 'renderHomeCampaignField'),
			'pm_lead_filter_display_tab',
			'pm_lead_filter_display',
			array()
		);
		add_settings_field(
			'pm_lead_filter_aweber_key',
			__('Aweber Key', 'pm-lead-filter'),
			array($this, 'renderAweberKeyField'),
			'pm_lead_filter_services_tab',
			'pm_lead_filter_api_keys',
			array('name' => 'aw')
		);
		add_settings_field(
			'pm_lead_filter_mailchimp_key',
			__('Mailchimp Key', 'pm-lead-filter'),
			array($this, 'renderMailchimpKeyField'),
			'pm_lead_filter_services_tab',
			'pm_lead_filter_api_keys',
			array()
		);
		add_settings_field(
			'pm_lead_filter_support_key',
			__('Plugin Mill Support Key', 'pm-lead-filter'),
			array($this, 'renderLicenseKeyField'),
			'pm_lead_filter_license_tab',
			'license_section',
			array('name' => 'support')
		);
	}

	/*
	 * Render Sections
	 */
	public function renderGeneralSection() {
		$campaign_list = new Pm_Lead_Filter_Campaign_Create( $this->options );
		$campaign_list->DisplayListing();
	}
	public function renderDisplaySection(){
	}
	public function renderApiKeysSection() {
		echo "API Keys Section";
	}
	public function renderLicenseSection() {
		echo "License Key Section";
	}

	/*
	 * Render fields
	 */
	public function renderHomepageField( $args ) {
		$display = $this->options->get('display_settings');
		?>
		<label><input type="checkbox" id="enableHompage" name="pm_lead_filter_opts[enable_home]" <?php checked( $display['enable_home'], 'on', true ); ?>> Yes</label>
		<?php
	}
	public function renderHomeCampaignField( $args ) {
		$display = $this->options->get('display_settings');
		?>
		<select name="pm_lead_filter_opts[home_campaign]" id="homeCampaignId">
			<option value="0">Select Campaign</option>
			<?php
			foreach ($this->campaigns as $id => $c) {
				?>
				<option value="<?php echo $id; ?>" <?php selected( $display['home_campaign'], $id, true ); ?>><?php echo $c['campaign_name']; ?></option>
				<?php
			}
			?>
		</select>
		<?php
	}
	public function renderShowAllField( $args ) {
		// Not developed. Perhaps later?
		?>
		Display popup on all fields, disable per page basis
		<?php
	}
	public function renderAweberKeyField( $args ) {
		$saved_opts = $this->options->get('email_services');
		$saved_opts['app_id'] = PM_LEAD_FLTR_AW_APP_ID;
		$saved_opts['opt_name'] = 'pm_lead_filter_opts';
		$saved_opts['slug'] = 'pm_lead_filter';
		$aw_consumerKey = ( empty( $saved_opts['aw_consumerKey'] ) ) ? '' : wp_strip_all_tags( $saved_opts['aw_consumerKey'] ) ;
		//echo "<pre>".print_r($saved_opts, true)."</pre>"; exit();
		
		$pm_lead_filter_aweber_api = new Pmill_Aweber_Api( $saved_opts );

		if( !empty( $aw_consumerKey ) ) { ?>
		<div id="aw_authorized">
			<span class="dashicons dashicons-yes"></span> <?php _e( 'Aweber account connected.', 'pm-lead-filter' ); ?>
			<label for=""><input id="service_deauthorize" type="checkbox" name="pm_lead_filter_opts[aw][aweber_deauth]" data-service="aweber" value="1"> <?php _e( 'Deauthorize', 'pm-lead-filter' ); ?></label>
		</div>
		<?php } ?>
		<div id="aw_unauthorized">
			<?php $pm_lead_filter_aweber_api->authorization_fields(); ?>
		</div>
		<?php
	}

	public function renderMailchimpKeyField( $args ) {
		$saved_opts = $this->options->get('email_services');
		$saved_opts['opt_name'] = 'pm_lead_filter_opts';
		$mc_key = ( empty( $saved_opts['mc_key'] ) ) ? '' : wp_strip_all_tags( $saved_opts['mc_key'] ) ;

		/*
		echo "<pre>".print_r($saved_opts, true)."</pre>";
        */
		$pm_lead_filter_mc_api = new Pmill_Mailchimp_Api( $saved_opts );
		$pm_lead_filter_mc_api->key_fields();
	}

	public function renderLicenseKeyField( $args ) {
		$support = ($this->shared_options) ? $this->shared_options['support']: array() ;
		$key_value = ( empty( $support['key'] ) ) ? '' : esc_attr( $support['key'] ) ;
		$input_class = ( empty( $key_value ) ) ? 'pm-support-key-show' : 'pm-support-key-hide' ;
		echo "<pre>".print_r($this->shared_options, true)."</pre>";
		?>
		<input type="text" id="pm-lead-filter-support-key" class="regular-text <?php echo $input_class; ?>" name="pm_lead_filter_opts[support_key]" value="" >
		<?php
		if( !empty( $support['activation_code'] ) ) {
			if( $support['activation_code'] != 'ok' ) {
				echo $support['activation_message'].'. '.__('De-activate from other sites before activating on this site.', 'pm-lead-filter');
			} else {
				?>
				<p class="pm-lead-filter-key-message">Your license is <span class="pm-lead-filter-key-active">ACTIVE!</span></p>
				<button id="pm-lead-filter-reenter-key" class="button button-primary">Enter/Re-enter Key</button>
				<button id="deactivate-key" class="button secondary-button">De-activate Key</button>
				<div id="deactivate-response"></div>
				<?php
			}
		}
	}

	/*
	 * Frame footer
	 */
	public function footer_frame() {
		$render_frame = new Pm_Lead_Filter_Campaign_Create(array());
		$render_frame->newCampaign();
	}

	/*
	 * AJAX functions
	 */
	public function load_admin_editor() {
		$content = stripslashes( $_POST['content'] );
		$id = stripslashes( $_POST['id'] );
		$settings = array(
			'media_buttons' => false,
			'quicktags' => false,
			);
		wp_editor( $content, $id, $settings );
		\_WP_Editors::enqueue_scripts();
		print_footer_scripts();
		\_WP_Editors::editor_js();
		exit();
	}
	public function save_campaign() {
		if ( !wp_verify_nonce( $_POST['nonce'], 'save_campaign' ) )
			die();

		// Send input to be sanitized
		$sanitized_input = $this->sanitize_campaign_input( $_POST );
		$campaignid = ( empty( $_POST['campaignid'] ) ) ? '' : sanitize_text_field( $_POST['campaignid'] );

		if( $_POST['operation'] === 'new-campaign' ) {
			if( empty( $this->campaigns ) ) {
				$this->campaigns[1] = $sanitized_input;
			} else {
				$this->campaigns[] = $sanitized_input;
			}
		} else {
			$this->campaigns[$campaignid] = $sanitized_input;
		}
		//echo "<pre>".print_r($_POST, true)."</pre>"; exit();

		update_option( 'pm_lead_filter_campaigns', $this->campaigns, null );

		exit();
	}

	/*
	 * Sanitize input
	 */
	private function sanitize_campaign_input( $input ) {
		$valid_input['campaign_name'] = ( empty($input['campaign_name']) ) ? '' : sanitize_text_field( $input['campaign_name'] );
		$valid_input['campaign_content'] = ( empty($input['campaign_content']) ) ? '' : stripslashes( $input['campaign_content'] );
		$valid_input['text_color'] = ( !empty( $input['text_color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['text_color'] ) == '1' ) ) ? sanitize_text_field( $input['text_color'] ) : '' ;
		$valid_input['popup_delay'] = ( empty( $input['popup_delay'] ) && is_numeric( $input['popup_delay'] ) ) ? '' : sanitize_text_field( $input['popup_delay'] ) ;
		$valid_input['cookie_duration'] = ( empty( $input['cookie_duration'] ) && is_numeric( $input['cookie_duration'] ) ) ? '' : sanitize_text_field( $input['cookie_duration'] ) ;
		$valid_input['background']['type'] = ( empty($input['background']['type']) ) ? '' : sanitize_text_field( $input['background']['type'] ) ;
		$valid_input['background']['color'] = ( !empty( $input['background']['color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['background']['color'] ) == '1' ) ) ? sanitize_text_field( $input['background']['color'] ) : '' ;
		$valid_input['background']['bg_img'] = ( empty( $input['background']['bg_img'] ) ) ? '' : sanitize_url( $input['background']['bg_img'] ) ;
		$valid_input['button1']['label'] = ( empty( $input['button1']['label'] ) ) ? '' : sanitize_text_field( $input['button1']['label'] ) ;
		$valid_input['button1']['text_color'] = ( !empty( $input['button1']['text_color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['button1']['text_color'] ) == '1' ) ) ? sanitize_text_field( $input['button1']['text_color'] ) : '' ;
		$valid_input['button1']['color'] = ( !empty( $input['button1']['color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['button1']['color'] ) == '1' ) ) ? sanitize_text_field( $input['button1']['color'] ) : '' ;
		$valid_input['button1']['cta'] = ( empty( $input['button1']['cta'] ) ) ? '' : stripslashes( $input['button1']['cta'] ) ;
		$valid_input['button1']['email_service'] = ( empty( $input['button1']['email_service'] ) ) ? '' : sanitize_text_field( $input['button1']['email_service'] ) ;
		$valid_input['button1']['list'] = ( empty( $input['button1']['list'] ) ) ? '' : wp_kses( $input['button1']['list'], $this->allowed_tags() ) ;
		$valid_input['button1']['noNameField'] = ( empty( $input['button1']['noNameField'] ) ) ? '' : 1 ;
		$valid_input['button1']['optin_label'] = ( empty( $input['button1']['optin_label'] ) ) ? '' : sanitize_text_field( $input['button1']['optin_label'] ) ;
		$valid_input['button1']['thank_msg'] = ( empty( $input['button1']['thank_msg'] ) ) ? '' : wp_kses_post( $input['button1']['thank_msg'] );
		$valid_input['button1']['subbed_msg'] = ( empty( $input['button1']['subbed_msg'] ) ) ? '' : wp_kses_post( $input['button1']['subbed_msg'] );

		$valid_input['button2']['label'] = ( empty( $input['button2']['label'] ) ) ? '' : sanitize_text_field( $input['button2']['label'] ) ;
		$valid_input['button2']['text_color'] = ( !empty( $input['button2']['text_color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['button2']['text_color'] ) == '1' ) ) ? sanitize_text_field( $input['button2']['text_color'] ) : '' ;
		$valid_input['button2']['color'] = ( !empty( $input['button2']['color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['button2']['color'] ) == '1' ) ) ? sanitize_text_field( $input['button2']['color'] ) : '' ;
		$valid_input['button2']['cta'] = ( empty( $input['button2']['cta'] ) ) ? '' : stripslashes( $input['button2']['cta'] ) ;
		$valid_input['button2']['email_service'] = ( empty( $input['button2']['email_service'] ) ) ? '' : sanitize_text_field( $input['button2']['email_service'] ) ;
		$valid_input['button2']['list'] = ( empty( $input['button2']['list'] ) ) ? '' : wp_kses( $input['button2']['list'], $this->allowed_tags() ) ;
		$valid_input['button2']['noNameField'] = ( empty( $input['button2']['noNameField'] ) ) ? '' : 1 ;
		$valid_input['button2']['optin_label'] = ( empty( $input['button2']['optin_label'] ) ) ? '' : sanitize_text_field( $input['button2']['optin_label'] ) ;
		$valid_input['button2']['thank_msg'] = ( empty( $input['button2']['thank_msg'] ) ) ? '' : wp_kses_post( $input['button2']['thank_msg'] );
		$valid_input['button2']['subbed_msg'] = ( empty( $input['button2']['subbed_msg'] ) ) ? '' : wp_kses_post( $input['button2']['subbed_msg'] );

		return $valid_input;
	}
	public function sanitize( $input ) {
		$saved_opts = $this->options;
		$email_services = $saved_opts->get('email_services');		
		$now = new DateTime( null, new DateTimeZone('UTC') );
		$reverifyDate = strtotime('+30day', $now->getTimestamp());

		// Figure out which tab is submitted
		$services_tab = ( !empty( $input['submit-services'] ) ? true : false );
		$display_tab = ( !empty( $input['submit-display'] ) ? true : false );
		$license_tab = ( !empty( $input['submit-license'] ) ? true : false );

		// Save based on tab
		if( $services_tab ) {
			// Sanitize
			if( $input['aw']['aweber_deauth'] == 1 ) {
				$valid_services['aweber_auth_code'] = '';
				$valid_services['aw_consumerKey'] = '';
				$valid_services['aw_consumerSecret'] = '';
				$valid_services['aw_accessSecret'] = '';
				$valid_services['mc_key'] = !empty( $input['mc']['mc_key'] ) ? sanitize_text_field( $input['mc']['mc_key'] ) : $email_services['mc_key'] ;
			} else {
				$valid_services['aweber_auth_code'] = !empty( $input['aw']['aweber_auth_code'] ) ? sanitize_text_field( $input['aw']['aweber_auth_code'] ) : $email_services['aweber_auth_code'] ;
				$valid_services['aw_consumerKey'] = !empty( $input['aw']['aw_consumerKey'] ) ? sanitize_text_field( $input['aw']['aw_consumerKey'] ) : $email_services['aw_consumerKey'] ;
				$valid_services['aw_consumerSecret'] = !empty( $input['aw']['aw_consumerSecret'] ) ? sanitize_text_field( $input['aw']['aw_consumerSecret'] ) : $email_services['aw_consumerSecret'] ;
				$valid_services['aw_accessKey'] = !empty( $input['aw']['aw_accessKey'] ) ? sanitize_text_field( $input['aw']['aw_accessKey'] ) : $email_services['aw_accessKey'] ;
				$valid_services['aw_accessSecret'] = !empty( $input['aw']['aw_accessSecret'] ) ? sanitize_text_field( $input['aw']['aw_accessSecret'] ) : $email_services['aw_accessSecret'] ;
				$valid_services['mc_key'] = !empty( $input['mc']['mc_key'] ) ? sanitize_text_field( $input['mc']['mc_key'] ) : $email_services['mc_key'] ;
			}

			$valid_input = array(
				'display_settings' => $saved_opts->get('display_settings'),
				'email_services' => $valid_services
				);
		} elseif ( $display_tab ) {
			$valid_display_settings['enable_home'] = empty( $input['enable_home'] ) ? '' : 'on' ;
			$valid_display_settings['home_campaign'] = empty( $input['home_campaign'] ) ? '0' : stripslashes( $input['home_campaign'] );

			$valid_input = array(
				'display_settings' => $valid_display_settings,
				'email_services' => $saved_opts->get('email_services')
				);
			//echo "<pre>".print_r($valid_input, true)."</pre>"; exit();
		} elseif ( $license_tab ) {
			// Sanitize
			$valid_shared_input['support']['key'] = isset( $input['support_key'] ) ? sanitize_key( $input['support_key'] ) : $shared_options['support']['key'];

			// Verify support license
			$licensing = new Pm_PluginMill_Licensing($valid_shared_input['support']['key'], $this->admin->get_plugin_license_api());
			$verify = $licensing->verifyPluginLicense();

			if( $verify['valid'] ) {
				// Try activating key
				$activate = $licensing->activatePluginLicense( $shared_options['support'] );
				if( $activate['activation_code'] == 'ok' ) {
					$valid_shared_input['support']['key'] = $valid_shared_input['support']['key'];
					$valid_shared_input['support']['reverifydate'] = $reverifyDate ;
					$valid_shared_input['support']['activation_code'] = $activate['activation_code'];
					$valid_shared_input['support']['activation_message'] = $activate['activation_message'];
					$valid_shared_input['support']['activation_cache'] = $activate['activation_cache'];
					$message = $verify['message'];
					$type = 'updated';
				} else {
					$valid_shared_input['support']['key'] = '';
					$valid_shared_input['support']['reverifydate'] = '';
					$valid_shared_input['support']['activation_code'] = $activate['activation_code'];
					$valid_shared_input['support']['activation_message'] = $activate['activation_message'];
					$valid_shared_input['support']['activation_cache'] = '';
					$message = $activate['activation_message'];
					$type = 'error';
				}
			} else {
				$message = __($verify['message'].'. Please verify and re-enter Plugin Mill Support Key.', 'pm-lead-filter' );
				$type = 'error';
				$valid_shared_input = array( 'support' => array() );
			}

			//echo "<pre>",print_r($valid_shared_input, true),"</pre>";exit();
			// Update shared options
			update_option( '_pm_pluginmill_shared', $valid_shared_input, null );

			add_settings_error( 'pm_lead_filter_opts', esc_attr('settings_updated'), $message, $type );

			// Use Saved settings for other tabs
			$valid_input['keys'] = ( $this->options->get('keys') ) ? $this->options->get('keys') : array() ;
		}

		//echo "<pre>",print_r($valid_input, true),"</pre>";exit();

		return $valid_input;

		add_settings_error( 'pm_lead_filter_opts', esc_attr('settings_updated') );
	}

	// NOTE: Form elements must be enclosed in double quotes. Single quotes will not work
	public function allowed_tags() {
		$allowed = array(
			'form' => array(
				'action' => true,
				'method' => true,
				'id' => true,
				'accept' => true,
				'accept-charset' => true,
				'enctype' => true,
				'name' => true,
				'target' => true
				),
			'input' => array(
				'type' => true,
				'name' => true,
				'value' => true
				),
			'div' => array(
				'id' => true,
				'class' => true,
				)
			);
		return $allowed;
	}

	public function campaignLookup() {
		$campaignid = ( !empty( $_POST['campaignid'] ) && is_numeric( $_POST['campaignid'] ) ) ? stripslashes( $_POST['campaignid'] ) : '0' ;
		$this->campaigns[$campaignid]['campaign_name'] = stripslashes( $this->campaigns[$campaignid]['campaign_name'] );
		$this->campaigns[$campaignid]['button1']['label'] = stripslashes( $this->campaigns[$campaignid]['button1']['label'] );
		$this->campaigns[$campaignid]['button1']['optin_label'] = stripslashes( $this->campaigns[$campaignid]['button1']['optin_label'] );
		$this->campaigns[$campaignid]['button1']['thank_msg'] = stripslashes( $this->campaigns[$campaignid]['button1']['thank_msg'] );
		$this->campaigns[$campaignid]['button1']['subbed_msg'] = stripslashes( $this->campaigns[$campaignid]['button1']['subbed_msg'] );
		$this->campaigns[$campaignid]['button2']['label'] = stripslashes( $this->campaigns[$campaignid]['button2']['label'] );
		$this->campaigns[$campaignid]['button2']['optin_label'] = stripslashes( $this->campaigns[$campaignid]['button2']['optin_label'] );
		$this->campaigns[$campaignid]['button2']['thank_msg'] = stripslashes( $this->campaigns[$campaignid]['button2']['thank_msg'] );
		$this->campaigns[$campaignid]['button2']['subbed_msg'] = stripslashes( $this->campaigns[$campaignid]['button2']['subbed_msg'] );

		echo json_encode( $this->campaigns[$campaignid] );

		die();
	}

	public function dupCampaign() {
		$campaignid = ( empty( $_POST['campaignid'] ) && is_numeric( $_POST['campaignid'] ) ) ? '' : esc_attr( $_POST['campaignid'] ) ;

		$campaign = $this->campaigns[$campaignid];
		$campaign['campaign_name'] = $campaign['campaign_name'].' copy';
		$this->campaigns[] = $campaign;

		update_option( 'pm_lead_filter_campaigns', $this->campaigns, null );

		die();
	}

	public function deleteCampaign() {
		$campaignid = ( empty( $_POST['campaignid'] ) && is_numeric( $_POST['campaignid'] ) ) ? '' : esc_attr( $_POST['campaignid'] ) ;
		unset( $this->campaigns[$campaignid] );
		update_option( 'pm_lead_filter_campaigns', $this->campaigns, null );

		die();
	}

	/*
	 * Runs the class
	 */
	public function run() {
		add_action( 'admin_init', array($this, 'configure') );
		add_action( 'admin_menu', array($this, 'addOptionsPage') );
		add_action( 'admin_footer-settings_page_pm_lead_filter', array($this, 'footer_frame') );
		add_action( 'wp_ajax_pm_lead_filter_admineditor', array($this, 'load_admin_editor') );
		add_action( 'wp_ajax_pm_lead_filter_save_campaign', array($this, 'save_campaign') );
		add_action( 'wp_ajax_pm_lead_filter_campaignLookup', array($this, 'campaignLookup') );
		add_action( 'wp_ajax_pm_lead_filter_dupCampaign', array($this, 'dupCampaign') );
		add_action( 'wp_ajax_pm_lead_filter_deleteCampaign', array($this, 'deleteCampaign') );
		$campaign_create = new Pm_Lead_Filter_Campaign_Create( $this->options );
		$campaign_create->run();
		$aweber_api = new Pmill_Aweber_Api($this->options->get('email_services'));
		$aweber_api->run();
	}
}