<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.pluginmill.com
 * @since      9.1.0.0
 *
 * @package    Pm_Lead_Filter
 * @subpackage Pm_Lead_Filter/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Pm_Lead_Filter
 * @subpackage Pm_Lead_Filter/admin
 * @author     Lynette Chandler <lynette@pluginmill.com>
 */
class Pm_Lead_Filter_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    9.1.0.0
	 * @access   private
	 * @var      string    $plugin_slug    The ID of this plugin.
	 */
	private $plugin_slug;

	/**
	 * The version of this plugin.
	 *
	 * @since    9.1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    9.1.0.0
	 * @param      string    $plugin_slug       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_slug, $version ) {

		$this->plugin_slug = $plugin_slug;
		$this->version = $version;
		$this->load_dependencies();

	}

	/**
	 * Load dependent files
	 */
	private function load_dependencies() {
		require_once plugin_dir_path( dirname( __FILE__ ) ).'includes/class-pm-lead-filter-options.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ).'admin/class-admin-page.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ).'admin/class-list-create-filter.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-pm-lead-filter-metabox.php';
		if( !class_exists('Pmill_Aweber_Api') ) {
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-aweber-api.php';
		}
		if( !class_exists('Pmill_Mailchimp_Api') ) {
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-mailchimp-api.php';
		}
		if( !class_exists('Am_LicenseChecker') ) {
			require_once plugin_dir_path( dirname( __FILE__ ) ). 'vendor/Am/LicenseChecker.php';
		}
		if( !class_exists('Pm_PluginMill_Licensing') ) {
			require_once plugin_dir_path( dirname( __FILE__ ) ). 'includes/class-pluginmill-licensing.php';
		}
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    9.1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pm_Lead_Filter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pm_Lead_Filter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_slug, plugin_dir_url( __FILE__ ) . 'css/pm-lead-filter-admin.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'wp-color-picker' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    9.1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pm_Lead_Filter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pm_Lead_Filter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$localized_opts = array(
			'title' => __('Select an image', 'pm-lead-filter'),
			'buttontext' => __('Use this', 'pm-lead-filter'),
			'nonce' => wp_create_nonce( 'save_campaign' ),
			'modalH1Edit' => __('Edit Campaign', 'pm-lead-filter')
			);
		wp_enqueue_media();
		wp_enqueue_script( $this->plugin_slug, plugin_dir_url( __FILE__ ) . 'js/pm-lead-filter-admin.js', array( 'jquery','media-views','media-models' ), $this->version, false );
		wp_localize_script( $this->plugin_slug, 'pm_lead_filter_campaign_obj', $localized_opts );
		wp_enqueue_script( 'wp-color-picker' );

	}

	/*
	 * Admin page
	 */
	private function admin_page() {
		$options = new Pm_Lead_Filter_Options( array() );
		$options = ( $options->load() ) ? $options->load() : array() ;
		$admin_page = new Pm_Lead_Filter_AdminPage( $options, $this->plugin_slug, $this->version );

		$admin_page->run();
	}

	/*
	 * Metabox
	 */
	private function metabox() {
		$options = new Pm_Lead_Filter_Options( array() );
		$options = ( $options->load_other('pm_lead_filter_campaigns') ) ? $options->load_other('pm_lead_filter_campaigns') : array() ;
		$metabox = new Pm_Lead_Filter_Metabox( $options, $this->plugin_slug, $this->version );
		$metabox->run();
	}

	/*
	 * Run the class
	 */
	public function run() {
		$this->admin_page();
		$this->metabox();
	}

}