jQuery(document).ready(function( $ ) {
	// Create a modal view.
	var modal = new wp.media.view.Modal({
		// A controller object is expected
		controller: { trigger: function() {} }
	});
	// Create a modal content view.
	var ModalCreateView = wp.Backbone.View.extend({
		className: 'pm-lead-filter-modal-content',
		template: wp.template( 'pm-lead-filter-modal' )
	});

	// Open modal when button clicked
	$(document).on('click', '#pm-lead-filter-create-new', function(event) {
		event.preventDefault();
		modal.content( new ModalCreateView() );
		modal.open();
		/* Color Picker */
		$('.color-picker').wpColorPicker({
			palettes: true,
		});

		$('#save-campaign').addClass('new-campaign');
		$('#save-campaign').attr('data-operation', 'new-campaign');
	});

	// Edit campaign button
	$(document).on('click', '.editCampaign', function(e) {
		e.preventDefault();
		modal.content( new ModalCreateView({
			className: 'pm-lead-filter-edit-campaign'
		}));
		modal.open();

		// Lookup campaign
		var data = {
			'action': 'pm_lead_filter_campaignLookup',
			'campaignid': $(this).data('campaignid')
		}
		$.post(ajaxurl, data, function(response) {
			var campaigndata = JSON.parse(response);
			populate_edit_form(campaigndata);

			$('#campaign-title').html(pm_lead_filter_campaign_obj.modalH1Edit);
			$('#save-campaign').addClass('edit-campaign');
			$('#save-campaign').attr('data-campaignid', data.campaignid );
			$('#save-campaign').attr('data-operation', 'edit-campaign');
		});

	});

	// File upload / select
	$(document).on('click', '.choose-campaign-img', function(e) {
		e.preventDefault();
		var current = $(this);
		
		var frame = new wp.media.view.MediaFrame.Select({
			multiple: false,
			title: pm_lead_filter_campaign_obj.title,
			button: {
				text: pm_lead_filter_campaign_obj.buttontext
			}
		});

		frame.on('select', function() {
			var selection = frame.state().get('selection').first().toJSON();
			current.prev().css('background-image', 'url('+selection.url+')').addClass('pm-lead-filter-img-size');
			current.next().val(selection.url);
		});
		frame.open();
	});

	// Email API
	// Aweber
	$('#aweber_auth_code').on('paste', function(e) {
		setTimeout(function() {
			$('#AWCreds').text('One moment while we connect to Aweber');
			var aw_code = $('#aweber_auth_code').val();
			var data = {
				'action': 'pmill_aw_connect',
				'aw_code': aw_code
			};

			$.post(ajaxurl, data, function(jsonResponse) {
				console.log('Data sent');
				console.log(jsonResponse);
				var response = jQuery.parseJSON(jsonResponse);
				if( typeof response == 'object' ) {
					$('#AWCreds').text('Great! Aweber responded. Let\'s check if the information is valid.');
					if(response['aw_consumerKey'] != null) {
						$('#AWCreds').text('Information is valid. One moment.');
						$('#aw_consumerKey').val(response['aw_consumerKey']);
						$('#aw_consumerSecret').val(response['aw_consumerSecret']);
						$('#aw_accessKey').val(response['aw_accessKey']);
						$('#aw_accessSecret').val(response['aw_accessSecret']);
						$('#AWCreds').text('Information received successful. Please Save Settings Now');
					}
				} else {
					$('#AWCreds').text('Something is wrong. Usually the key has become invalid or there is a connection issue. Please perform authorization again.');
				}
			});
		}, 300);		
	});

	// Select email list
	$(document).on('change', '.email-service', function(e) {
		pm_lead_filter_retrieve_list( $(this).val(), $(this).attr('id'), 'none' );
	});

	// Save campaign
	$(document).on('click', '#save-campaign', function(e) {
		e.preventDefault();
		if( $('#background-type').val() === 'color' ) {
			var background_color = $('#background-color').val();
			var campaign_bg_img = '';
		} else {
			var background_color = '';
			var campaign_bg_img =  $('#campaign-bg-img').val();
		}

		var data = {
			'action': 'pm_lead_filter_save_campaign',
			'nonce': pm_lead_filter_campaign_obj.nonce,
			'operation': $(this).data('operation'),
			'campaignid': $(this).data('campaignid'),
			'campaign_name': $('#campaign-name').val(),
			'campaign_content': $('#campaign-content').val(),
			'text_color': $('#content-text-color').val(),
			'popup_delay': $('#popup-delay').val(),
			'cookie_duration': $('#cookie-duration').val(),
			'background': {
				'type': $('#background-type').val(),
				'color': background_color,
				'bg_img': campaign_bg_img,
			},			
			'button1': {
				'label': $('#label_button1').val(),
				'text_color': $('#text_color_btn1').val(),
				'color': $('#color_btn1').val(),
				'cta': $('#cta-btn1').val(),
				'email_service': $('#service-btn1').val(),
				'list': $('#select-list-btn1').val(),
				'noNameField': $('#noNameField-btn1:checked').val(),
				'optin_label': $('#optin-label-btn1').val(),
				'thank_msg': $('#thank-msg-btn1').val(),
				'subbed_msg': $('#subbed-msg-btn1').val()
			},
			'button2': {
				'label': $('#label_button2').val(),
				'text_color': $('#text_color_btn2').val(),
				'color': $('#color_btn2').val(),
				'cta': $('#cta-btn2').val(),
				'email_service': $('#service-btn2').val(),
				'list': $('#select-list-btn2').val(),
				'noNameField': $('#noNameField-btn2:checked').val(),
				'optin_label': $('#optin-label-btn2').val(),
				'thank_msg': $('#thank-msg-btn2').val(),
				'subbed_msg': $('#subbed-msg-btn2').val()
			},
		}

		$.post(ajaxurl, data, function (response) {
			//console.log(response);
			//$('#pm-lead-filter-campaign-list').html(response);
			modal.close();
			location.reload(true);
		});
	});

	// Duplicate campaign
	$(document).on('click', '.dupCampaign', function(e) {
		e.preventDefault();
		var data = {
			'action': 'pm_lead_filter_dupCampaign',
			'campaignid': $(this).attr('data-campaignid')
		}

		$.post(ajaxurl, data, function(response) {
			//console.log(response);
			location.reload(true);
		});
	});

	// Delete campaign
	$(document).on('click', '.delCampaign', function(e) {
		var data = {
			'action': 'pm_lead_filter_deleteCampaign',
			'campaignid': $(this).attr('data-campaignid')
		}

		$.post(ajaxurl, data, function(response) {
			//console.log(response);
			location.reload(true);
		});
	});

	// Background Select
	$(document).on('change', '#background-type', function(event) {
		event.preventDefault();

		if( $(this).val() === 'color' ){
			$('#background-color-opts').show();
			$('#background-image-opts').hide();
		} else {
			$('#background-image-opts').show();
			$('#background-color-opts').hide();
		}
	});

	/*
	 * Helper functions
	 */
	// Retrieve email list from service
	function pm_lead_filter_retrieve_list( mailservice, button, selectList ) {
		var data = {
			'action': 'pm_lead_filter_get_lists',
			'mailservice': mailservice,
			'button': button
		};

		if( data.button === 'service-btn1' ) {
			$('#list-btn1 .preloader').show();
		} else {
			$('#list-btn2 .preloader').show();
		}

		$.post(ajaxurl, data, function(response) {
			if( data.button === 'service-btn1') {
				$('#list-btn1').html(response);
				$('#service-btn1').val(mailservice);
				$('#select-list-btn1').val(selectList);
				$('#list-btn1 .preloader').hide();
			} else {
				$('#list-btn2').html(response);
				$('#service-btn2').val(mailservice);
				$('#select-list-btn2').val(selectList);
				$('#list-btn2 .preloader').hide();
			}
		});
	}

	// Select the list saved or set to none when creating new campaign
	function set_saved_mailing_list( element, value ) {
		$(element).val(value);
	}

	function populate_edit_form( data ) {
		$('#campaign-name').val(data.campaign_name);
		$('#campaign-content').val(data.campaign_content);
		$('#content-text-color').val(data.text_color);
		$('#popup-delay').val(data.popup_delay);
		$('#cookie-duration').val(data.cookie_duration);
		$('#background-type').val(data.background.type);
		if( data.background.type === 'image' ){
			$('#campaign-bg-img').val(data.background.bg_img);
			$('.selected-background-image').css('background-image', 'url('+data.background.bg_img+')').addClass('pm-lead-filter-img-size');
		} else {
			$('#background-color').val(data.background.color);
		}
		$('#label_button1').val(data.button1.label);
		$('#text_color_btn1').val(data.button1.text_color);
		$('#color_btn1').val(data.button1.color);
		$('#cta-btn1').val(data.button1.cta);
		$('#optin-label-btn1').val(data.button1.optin_label);
		$('#thank-msg-btn1').val(data.button1.thank_msg);
		$('#subbed-msg-btn1').val(data.button1.subbed_msg);
		if( data.button1.noNameField === 1 ) {
			$('#noNameField-btn1').prop('checked', true);
		}
		$('#label_button2').val(data.button2.label);
		$('#text_color_btn2').val(data.button2.text_color);
		$('#color_btn2').val(data.button2.color);
		$('#cta-btn2').val(data.button2.cta);
		$('#thank-msg-btn2').val(data.button2.thank_msg);
		$('#subbed-msg-btn2').val(data.button2.subbed_msg);
		$('#optin-label-btn2').val(data.button2.optin_label);
		if( data.button2.noNameField === 1 ) {
			$('#noNameField-btn2').prop('checked', true);
		}

		pm_lead_filter_retrieve_list( data.button1.email_service, 'service-btn1', data.button1.list );
		pm_lead_filter_retrieve_list( data.button2.email_service, 'service-btn2', data.button2.list );

		$('.color-picker').wpColorPicker({
			palettes: true
		});

		if( data.background.type === 'color' ) {
			$('#background-color-opts').show();
		} else {
			$('#background-image-opts').show();
		}
	}
});