<?php
class Pm_Lead_Filter_Metabox {
	private $plugin_slug;
	private $version;

	public function __construct( $campaigns, $plugin_slug, $version ) {
		$this->plugin_slug = $plugin_slug;
		$this->version = $version;
		$this->campaigns = $campaigns;
		//$this->load_dependencies();
	}

	/*
	 * Add Metabox
	 */
	public function add_metabox( $post ) {
		add_meta_box(
			'pm_lead_filter_popup',
			PM_LEAD_FLTR_PLUGIN_NAME,
			array( $this, 'render_metabox' ),
			$post->post_type,
			'side',
			'default'
		);
	}

	/*
	 * Render Metabox
	 */
	public function render_metabox( $post, $args ) {
		$campaigns = $this->campaigns;
		wp_nonce_field( 'pm_lead_filter_nonce_action', 'pm_lead_filter_nonce' );
		$metadata = get_post_meta( $post->ID, 'pm_lead_filter_meta', true );
		//echo "<pre>".print_r($campaigns, true)."</pre>";
		?>
		<label><input type="checkbox" id="pm-lead-filter-checkbox" name="pm_lead_filter_enable" <?php checked( $metadata['enable'], 'on', true ); ?>> <?php _e('Enable', 'pm-lead-filter'); ?></label>
		<label>Campaign</label>
		<select name="pm_lead_filter_campaign" id="pm-lead-filter-campaign">
			<option value="0">Select Campaign</option>
			<?php
				foreach ($campaigns as $k => $campaign) {
			?>
			<option value="<?php echo $k; ?>" <?php if(!empty($metadata['campaignid'])) $this->loose_selected( $metadata['campaignid'], $k ); ?>><?php echo $campaign['campaign_name']; ?></option>
			<?php }	?>
		</select>
		<?php
	}

	public function loose_selected( $selected, $current ) {
		if( $selected == $current ) {
			echo 'selected';
		} else {
			return;
		}
	}

	/*
	 * Save metabox
	 */
	public function save_metabox( $post_id, $post ) {
		// Security authentication
		$nonce_name = isset( $_POST['pm_lead_filter_nonce'] ) ? $_POST['pm_lead_filter_nonce'] : '';
		$nonce_action = 'pm_lead_filter_nonce_action';
		$prev_value = get_post_meta( $post_id, 'pm_lead_filter_meta', true );
		//echo "Info sent:<br>".$current_meta_value."<hr><pre>".print_r($_POST, true)."</pre>"; exit();

		// Check if nonce is set
		if( !isset( $nonce_name ) )
			return;

		// Check if nonce is valid
		if( !wp_verify_nonce( $nonce_name, $nonce_action ) )
			return;

		// Check if user has permission
		if( !current_user_can( 'edit_post', $post_id ) )
			return;

		// Check if not autosave
		if( wp_is_post_autosave( $post_id ) )
			return;

		// Check if not a revision
		if( wp_is_post_revision( $post_id ) )
			return;

		// Check for multisite switch
		if( is_multisite() && ms_is_switched() )
			return $post_id;

		// Sanitize
		$data['enable'] = ( isset($_POST['pm_lead_filter_enable']) ) ? 'on' : '';
		$data['campaignid'] = ( isset($_POST['pm_lead_filter_campaign']) && intval($_POST['pm_lead_filter_campaign']) ) ? stripslashes($_POST['pm_lead_filter_campaign']) : '0' ;

		// Update
		update_post_meta( $post_id, 'pm_lead_filter_meta', $data, $prev_value );
	}

	/*
	 * Runs the class
	 */
	public function run() {
		add_action( 'add_meta_boxes_post', array( $this, 'add_metabox' ) );
		add_action( 'add_meta_boxes_page', array( $this, 'add_metabox' ) );
		add_action( 'save_post', array($this, 'save_metabox') );
	}
}